﻿/// <reference path="../../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/inedojq/inedojq_frameddialog.d.ts"/>
/// <reference path="../../../rubbish.ts"/>
var ErrorLogPage;
(function (ErrorLogPage) {
    var LogMessageViewModel = (function () {
        function LogMessageViewModel(data, detailsUrl) {
            this.id = data.id;
            this.message = data.message;
            this.date = data.date;
            this.level = data.level;
            this.category = data.category || 'N/A';
            this.read = ko.observable(data.read);
            this.detailsUrl = detailsUrl + '?messageId=' + data.id;
            this.statusCss = {
                warning: data.level < 30,
                error: data.level >= 30
            };
        }
        LogMessageViewModel.prototype.showDetails = function () {
            var _this = this;
            $.inedojq_frameddialog(this.detailsUrl, {
                dialogClose: function () {
                    _this.read(true);
                }
            });
        };
        return LogMessageViewModel;
    })();

    var ErrorLogViewModel = (function () {
        function ErrorLogViewModel(inputData) {
            var _this = this;
            this.inputData = inputData;
            this.messages = ko.observableArray();
            this.maxCount = ko.observable(25);
            this.minSeverity = ko.observable(20);
            this.loading = ko.observable(false);
            this.category = ko.observable('');
            this.categories = inputData.categories;
            this.update();

            var subscribe = function (handler) {
                var observables = [];
                for (var _i = 0; _i < (arguments.length - 1); _i++) {
                    observables[_i] = arguments[_i + 1];
                }
                for (var i = 0; i < observables.length; i++)
                    observables[i].subscribe(handler);
            };

            subscribe(function () {
                return _this.update();
            }, this.maxCount, this.minSeverity, this.category);
        }
        ErrorLogViewModel.prototype.updateFromData = function (messages) {
            var _this = this;
            this.messages(messages.map(function (d) {
                return new LogMessageViewModel(d, _this.inputData.detailsUrl);
            }));
        };

        ErrorLogViewModel.prototype.update = function () {
            var _this = this;
            if (!this.loading()) {
                this.loading(true);
                $.ajax({
                    type: 'POST',
                    url: this.inputData.updateUrl,
                    data: { maxCount: this.maxCount(), minSeverity: this.minSeverity(), category: this.category() },
                    success: function (results) {
                        _this.updateFromData(results);
                    },
                    complete: function () {
                        _this.loading(false);
                    }
                });
            }
        };

        ErrorLogViewModel.prototype.getCategoryName = function (item) {
            return item || '(all)';
        };

        ErrorLogViewModel.prototype.deleteMessage = function (item) {
            var _this = this;
            if (!this.loading()) {
                this.loading(true);
                $.ajax({
                    type: 'POST',
                    url: this.inputData.deleteUrl,
                    data: { id: item.id, maxCount: this.maxCount(), minSeverity: this.minSeverity(), category: this.category() },
                    success: function (results) {
                        _this.updateFromData(results);
                    },
                    complete: function () {
                        _this.loading(false);
                    }
                });
            }
        };

        ErrorLogViewModel.prototype.deleteAllMessages = function () {
            var _this = this;
            if (!this.loading()) {
                this.loading(true);
                $.ajax({
                    type: 'POST',
                    url: this.inputData.deleteAllUrl,
                    success: function () {
                        _this.messages.removeAll();
                    },
                    complete: function () {
                        _this.loading(false);
                    }
                });
            }
        };
        return ErrorLogViewModel;
    })();

    function Init(o) {
        ko.applyBindings(new ErrorLogViewModel(o));
    }
    ErrorLogPage.Init = Init;
})(ErrorLogPage || (ErrorLogPage = {}));
